"""Microcontroller pins"""

from adafruit_blinka import Enum
from adafruit_blinka.agnostic import board_id, platform

class Pin(Enum):
    """Reference Pin object"""
    def __init__(self, pin_id):
        """Identifier for pin, referencing platform-specific pin id"""
        self._id = pin_id

    def __repr__(self):
        import board
        for key in dir(board):
            if getattr(board, key) is self:
                return "board.{}".format(key)
        import microcontroller.pin as pin
        for key in dir(pin):
            if getattr(pin, key) is self:
                return "microcontroller.pin.{}".format(key)
        return repr(self)

# We intentionally are patching into this namespace so skip the wildcard check.
# pylint: disable=unused-wildcard-import,wildcard-import

if platform == "esp8266":
    from adafruit_blinka.microcontroller.esp8266 import *
elif platform == "stm32":
    from adafruit_blinka.microcontroller.stm32 import *
elif platform == "linux":
    if board_id == "raspi_3" or board_id == "raspi_2":
        from adafruit_blinka.microcontroller.raspi_23 import *
    else:
        raise NotImplementedError("Board not supported:", board_id)
else:
    raise NotImplementedError("Platform not supported:", platform)



"""Pins named after their chip name."""

from adafruit_blinka import agnostic

# We intentionally are patching into this namespace so skip the wildcard check.
# pylint: disable=unused-wildcard-import,wildcard-import

if agnostic.platform == "esp8266":
    from adafruit_blinka.microcontroller.esp8266.pin import *
elif agnostic.platform == "stm32":
    from adafruit_blinka.microcontroller.stm32.pin import *
elif agnostic.platform == "linux":
    if agnostic.board_id == "raspi_3" or agnostic.board_id == "raspi_2":
        from adafruit_blinka.microcontroller.raspi_23.pin import *
    else:
        raise NotImplementedError("Board not supported: ", agnostic.board_id)
else:
    raise NotImplementedError("Microcontroller not supported")



# The MIT License (MIT)
#
# Copyright (c) 2017 cefn for adafruit industries
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
"""
`board` - Define ids for available pins
=================================================

See `CircuitPython:board` in CircuitPython for more details.

* Author(s): cefn
"""
import sys

from adafruit_blinka.agnostic import board_id

if board_id == "feather_huzzah":
    from adafruit_blinka.board.feather_huzzah import *
elif board_id == "nodemcu":
    from adafruit_blinka.board.nodemcu import *
elif board_id == "pyboard":
    from adafruit_blinka.board.pyboard import *
elif board_id == "raspi_2" or board_id == "raspi_3":
    from adafruit_blinka.board.raspi_23 import *
elif "sphinx" in sys.modules:
    pass
else:
    raise NotImplementedError("Board not supported")
